@@ -5,10 +5,10 @@ use strict;
 
 use base qw/Template::Benchmark::Engine/;
 
-use Text::Xslate 0.1047;
-use Text::Xslate::Bridge::TT2;
+use Text::Xslate 0.1053;
+use Text::Xslate::Bridge::TT2 1.0002;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 our %feature_syntaxes = (
     literal_text              =>
